"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pagination import Pagination, PaginationTypedDict
from .polar_checkout_schemas_checkout import (
    PolarCheckoutSchemasCheckout,
    PolarCheckoutSchemasCheckoutTypedDict,
)
from polar_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ListResourceCheckoutTypedDict(TypedDict):
    items: List[PolarCheckoutSchemasCheckoutTypedDict]
    pagination: PaginationTypedDict


class ListResourceCheckout(BaseModel):
    items: List[PolarCheckoutSchemasCheckout]

    pagination: Pagination
