"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .productpricerecurringcustom import (
    ProductPriceRecurringCustom,
    ProductPriceRecurringCustomTypedDict,
)
from .productpricerecurringfixed import (
    ProductPriceRecurringFixed,
    ProductPriceRecurringFixedTypedDict,
)
from .productpricerecurringfree import (
    ProductPriceRecurringFree,
    ProductPriceRecurringFreeTypedDict,
)
from typing import Union


ProductPriceRecurringTypedDict = Union[
    ProductPriceRecurringFreeTypedDict,
    ProductPriceRecurringFixedTypedDict,
    ProductPriceRecurringCustomTypedDict,
]


ProductPriceRecurring = Union[
    ProductPriceRecurringFree, ProductPriceRecurringFixed, ProductPriceRecurringCustom
]
